@@ -21,7 +21,7 @@ import jinja2
 from strictyaml import (
     Any,
     Bool,
-    EmptyList,
+    Enum,
     load,
     Map,
     MapPattern,
@@ -31,30 +31,44 @@ from strictyaml import (
     Str,
 )
 
+from LbAPCommon import config
+
 try:
     FileNotFoundError
 except NameError:
     FileNotFoundError = IOError
 
-
 RE_APPLICATION = r"^([A-Za-z]+/)+v\d+r\d+(p\d+)?"
 RE_JOB_NAME = r"^[a-zA-Z0-9][a-zA-Z0-9_\-]+$"
 RE_OUTPUT_FILE_TYPE = r"^([A-Z][A-Z0-9_]+\.)+(ROOT|.?DST)$"
 RE_OPTIONS_FN = r"^\$?[a-zA-Z0-9/\.\-\+\=_]+$"
 RE_INFORM = r"^(?:[a-zA-Z]{3,}|[^@\s]+@[^@\s]+\.[^@\s]+)$"
 
+RE_ROOT_IN_TES = r"^\/.+$"
+RE_DDDB_TAG = r"^.{1,50}$"
+RE_CONDDB_TAG = r"^.{1,50}$"
+
 BASE_JOB_SCHEMA = {
     "application": Regex(RE_APPLICATION),
     "input": MapPattern(Str(), Any()),
     "output": Regex(RE_OUTPUT_FILE_TYPE) | Seq(Regex(RE_OUTPUT_FILE_TYPE)),
     "options": Regex(RE_OPTIONS_FN) | Seq(Regex(RE_OPTIONS_FN)),
-    "wg": Str(),
+    "wg": Enum(config.known_working_groups),
+    "inform": Regex(RE_INFORM) | Seq(Regex(RE_INFORM)),
+    # Automatic configuration
     "automatically_configure": Bool(),
-    "inform": EmptyList() | Regex(RE_INFORM) | Seq(Regex(RE_INFORM)),
+    "turbo": Bool(),
+    Optional("root_in_tes"): Regex(RE_ROOT_IN_TES),
+    Optional("simulation"): Bool(),
+    Optional("luminosity"): Bool(),
+    Optional("data_type"): Enum(config.known_data_types),
+    Optional("input_type"): Enum(config.known_input_types),
+    Optional("dddb_tag"): Regex(RE_DDDB_TAG),
+    Optional("conddb_tag"): Regex(RE_CONDDB_TAG),
 }
 DEFAULT_JOB_VALUES = {
     "automatically_configure": False,
-    "inform": [],
+    "turbo": False,
 }
 
 
